<!DOCTYPE TS><TS>
<context>
    <name>AudioCart</name>
    <message>
        <source>Copying audio...</source>
        <translation>Kopíruje se zvuk...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>WT</source>
        <translation>WT</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>POPIS</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DÉLKA</translation>
    </message>
    <message>
        <source>LAST PLAYED</source>
        <translation>NAPOSLEDY HRÁNO</translation>
    </message>
    <message>
        <source># OF PLAYS</source>
        <translation># PŘEHRÁNÍ</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation>PŮVOD</translation>
    </message>
    <message>
        <source>OUTCUE</source>
        <translation>OUTCUE</translation>
    </message>
    <message>
        <source>START DATE</source>
        <translation>POČÁTEČNÍ DATUM</translation>
    </message>
    <message>
        <source>END DATE</source>
        <translation>KONCOVÉ DATUM</translation>
    </message>
    <message>
        <source>DAYPART START</source>
        <translation>ZAČÁTEK ČÁSTI DNE</translation>
    </message>
    <message>
        <source>DAYPART END</source>
        <translation>KONEC ČÁSTI DNE</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NÁZEV</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="obsolete">Záběry</translation>
    </message>
    <message>
        <source>Cut Info</source>
        <translation>Informace o záběru</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nahrávat</translation>
    </message>
    <message>
        <source>Edit
Audio</source>
        <translation>Upravit
zvuk</translation>
    </message>
    <message>
        <source>Edit
Markers</source>
        <translation>Upravit
značky</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Zavést</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vyvést</translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation>Vytáhnout z CD</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation>Jste si jistý, že chcete smazat</translation>
    </message>
    <message>
        <source>Delete Cut</source>
        <translation>Smazat záběr</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>Událost RDCatch existuje</translation>
    </message>
    <message>
        <source>This cut is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation type="obsolete">Tento záběr se použije na jednu nebo více událostí RDCatch!
Přesto smazat?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vyprázdnit schránku</translation>
    </message>
    <message>
        <source>Deleting this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Smazání tohoto záběru vyprázdní také schránku.
Přesto smazat?</translation>
    </message>
    <message>
        <source>Clipboard Empty</source>
        <translation>Schránka prázdná</translation>
    </message>
    <message>
        <source>Clipboard is currently empty.</source>
        <translation>Schránka je nyní prázdná.</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Zvuk existuje</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Toto přepíše (smaže) stávající nahrávku.
Přesto pokračovat?</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[nový vozík]</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <source>1 Cut</source>
        <translation type="obsolete">1 záběr</translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation>RDLibrary</translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation type="obsolete">Soubor(y) se zvukem nelze smazat!</translation>
    </message>
    <message>
        <source>No audio is present in the cut!</source>
        <translation>V záběru není přítomen žádný zvuk!</translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more cuts are used in one or more RDCatch events!
Do you still want to delete?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio for cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No data copied - you must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CdRipper</name>
    <message>
        <source>Artist:</source>
        <translation>Umělec:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Jiné:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Cart</source>
        <translation>Použít hodnoty FreeDB na vozík</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Skladby</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>STOPA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DÉLKA</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>NÁZEV</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>JINÉ</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYP</translation>
    </message>
    <message>
        <source>&amp;Rip
Track</source>
        <translation>&amp;Vytáhnout
stopu</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizovat</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Úroveň:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dbFS</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Automatické zastřižení</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanály:</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Zvuk existuje</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Toto přepíše (smaže) stávající nahrávku.
Přesto pokračovat?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vyprázdnit schránku</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Vytažení tohoto záběru vyprázdní také schránku.
Přesto smazat?</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Kein Zugriff</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Kann die Datei nicht zum schreiben öffnen!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Zvuková stopa</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Datová stopa</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Vytažení dokončeno</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>Vytažení dokončeno!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Rip abgebrochen</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">Der Rip wurde abgebrochen.</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">Rip fehlgeschlagen</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">Der Ripper hat einen Fehler bemerkt.
Bitte überprüfen sie ihre Ripperkonfiguration und versuchen sie es erneut.</translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation>RDLibrary - Chyba při zavedení</translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation>RDLibrary - Chyba ve vytahovači</translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation>Zrušit
vytahování</translation>
    </message>
    <message>
        <source>Rip Track</source>
        <translation>Vytáhnout stopu</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary directory!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskRipper</name>
    <message>
        <source>Rip Disk</source>
        <translation>Vytáhnout z CD</translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation>Umělec:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Jiné:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Carts</source>
        <translation>Použít hodnoty FreeDB na vozíky</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Stopy</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>STOPA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DÉLKA</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>NÁZEV</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>JINÉ</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYP</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>ZÁBĚR</translation>
    </message>
    <message>
        <source>Disk Progress</source>
        <translation>Celkový postup</translation>
    </message>
    <message>
        <source>Track Progress</source>
        <translation>Postup stopy</translation>
    </message>
    <message>
        <source>Set
&amp;Cut</source>
        <translation>Nastavit
&amp;záběr</translation>
    </message>
    <message>
        <source>Set All
&amp;New Carts</source>
        <translation>Nastavit všechny
&amp;nové vozíky</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizovat</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Úroveň:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dbFS</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Automatické zastřižení</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanály:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Cut Conflict</source>
        <translation>Střet záběru</translation>
    </message>
    <message>
        <source>That cut has already been assigned a track!</source>
        <translation>Tento záběr již byl přiřazen ke stopě!</translation>
    </message>
    <message>
        <source>Cut Exists</source>
        <translation>Záběr existuje</translation>
    </message>
    <message>
        <source>A recording already exists.
Do you want to overwrite it?</source>
        <translation>Nahrávka již existuje.
Chcete ji přepsat?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vyprázdnit schránku</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Vytažení tohoto záběru vyprázdní také schránku.
Přesto smazat?</translation>
    </message>
    <message>
        <source>Library Error</source>
        <translation>Chyba v knihovně</translation>
    </message>
    <message>
        <source>Insufficient free carts available in group!</source>
        <translation>Nedostatek volných vozíků ve skupině!</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Zvuková stopa</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Datová stopa</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Vytažení dokončeno</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>Vytažení dokončeno!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Rip abgebrochen</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">Der Rip wurde abgebrochen.</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">Rip fehlgeschlagen</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">Der Ripper hat einen Fehler bemerkt.
Bitte überprüfen sie ihre Ripperkonfiguration und versuchen sie es erneut.</translation>
    </message>
    <message>
        <source>Total Progress</source>
        <translation>Celkový postup</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Kein Zugriff</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Kann die Datei nicht zum schreiben öffnen!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>&amp;Rip
Disc</source>
        <translation>Vytáhnout
z CD</translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation>RDLibrary - Chyba při zavedení</translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation>RDLibrary - Chyba ve vytahovači</translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation>Zrušit
vytahování</translation>
    </message>
    <message>
        <source>Rip
Disk</source>
        <translation>Vytáhnout
z CD</translation>
    </message>
    <message>
        <source>Rip aborted!</source>
        <translation>Vytažení
zrušeno!</translation>
    </message>
    <message>
        <source>Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary directory!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditCart</name>
    <message>
        <source>Number:</source>
        <translation>Číslo:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Skupina:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Average Length:</source>
        <translation>Průměrná délka:</translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation>Vynutit délku</translation>
    </message>
    <message>
        <source>Forced Length:</source>
        <translation>Vynucená délka:</translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation>Zachovat výšku tónu</translation>
    </message>
    <message>
        <source>&amp;Title:</source>
        <translation>&amp;Název:</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>&amp;Počáteční datum:</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>&amp;Koncové datum:</translation>
    </message>
    <message>
        <source>&amp;Artist:</source>
        <translation>&amp;Umělec:</translation>
    </message>
    <message>
        <source>&amp;Year Released:</source>
        <translation>&amp;Rok vydání:</translation>
    </message>
    <message>
        <source>U&amp;sage:</source>
        <translation>Po&amp;užití:</translation>
    </message>
    <message>
        <source>Scheduler Codes</source>
        <translation>Kódy rozvrhovače</translation>
    </message>
    <message>
        <source>Al&amp;bum:</source>
        <translation>Al&amp;bum:</translation>
    </message>
    <message>
        <source>Re&amp;cord Label:</source>
        <translation>Označení &amp;nahrávky:</translation>
    </message>
    <message>
        <source>C&amp;lient:</source>
        <translation>&amp;Zákazník:</translation>
    </message>
    <message>
        <source>A&amp;gency:</source>
        <translation>A&amp;gentura:</translation>
    </message>
    <message>
        <source>&amp;Publisher:</source>
        <translation>Vy&amp;davatel:</translation>
    </message>
    <message>
        <source>Compos&amp;er:</source>
        <translation>Skladat&amp;el:</translation>
    </message>
    <message>
        <source>&amp;User Defined:</source>
        <translation>Stanoveno už&amp;ivatelem:</translation>
    </message>
    <message>
        <source>Schedule Cuts:</source>
        <translation type="obsolete">Rozvrhnout záběry:</translation>
    </message>
    <message>
        <source>Execute Asynchronously</source>
        <translation>Vykonat asynchronně</translation>
    </message>
    <message>
        <source>&amp;Edit
Script</source>
        <translation>&amp;Upravit
skript</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>AUDIO</source>
        <translation>ZVUK</translation>
    </message>
    <message>
        <source>MACRO</source>
        <translation>MAKRO</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>NEZNÁMÝ</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">Postupně</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Náhodně</translation>
    </message>
    <message>
        <source></source>
        <translation>Project-Id-Version: amarok
Report-Msgid-Bugs-To: http://bugs.kde.org
POT-Creation-Date: 2010-05-20 04:55+0200
PO-Revision-Date: 2010-05-22 09:34+0200
Last-Translator: Pavel Fric
Language-Team: Czech &lt;kde-i18n-doc@kde.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Generator: Lokalize 1.0
Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n&gt;=2 &amp;&amp; n&lt;=4) ? 1 : 2;
</translation>
    </message>
    <message>
        <source>Missing Title</source>
        <translation>Chybí název</translation>
    </message>
    <message>
        <source>You must provide at least a Cart Title!</source>
        <translation>Musíte zadat alespoň název vozíku!</translation>
    </message>
    <message>
        <source>Length Mismatch</source>
        <translation>Nesoulad v délkách</translation>
    </message>
    <message>
        <source>One or more cut lengths exceed the timescaling
limits of the system!  Do you still want to save?</source>
        <translation>Jedna nebo více záběrových délek překračuje časové omezení
systému! Přesto chcete uložit?</translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation>Zdvojený název</translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation>Název vozíku musí být jedinečný!</translation>
    </message>
    <message>
        <source>&amp;Edit
Notes</source>
        <translation>&amp;Upravit
poznámky</translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cond&amp;uctor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Song &amp;ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Beats per Minute:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMacro</name>
    <message>
        <source>Edit Macro</source>
        <translation>Upravit makro</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>EditNotes</name>
    <message>
        <source>Notes for cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>EditSchedulerCodes</name>
    <message>
        <source>Select Scheduler Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assigned Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ASSIGN to Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>REMOVE from Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Library Filter</source>
        <translation>Filtr knihovny</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Vyprázdnit</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>&amp;Filter:</source>
        <translation>&amp;Filtr:</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished">Typ:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zavřít</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished">VŠE</translation>
    </message>
    <message>
        <source>Cart Data Dump (fixed width)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Data Dump (CSV)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepend Field Names</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MacroCart</name>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>LINE</source>
        <translation>ŘÁDEK</translation>
    </message>
    <message>
        <source>COMMAND</source>
        <translation>PŘÍKAZ</translation>
    </message>
    <message>
        <source>Macros</source>
        <translation>Makra</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Run
Line</source>
        <translation>Spustit
řádek</translation>
    </message>
    <message>
        <source>Run
Cart</source>
        <translation>Spustit
vozík</translation>
    </message>
    <message>
        <source>--- End of cart ---</source>
        <translation>--- Konec vozíku ---</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Please Wait...</source>
        <translation>Počkejte, prosím...</translation>
    </message>
    <message>
        <source>rdlibrary : </source>
        <translation>rdlibrary: </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Nelze spojit</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Hledat</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Skupina</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation>Kódy rozvrhovače:</translation>
    </message>
    <message>
        <source>Show Audio Carts</source>
        <translation>Ukázat zvukové karty</translation>
    </message>
    <message>
        <source>Show Macro Carts</source>
        <translation>Ukázat makro karty</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>VOZÍK</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>SKUPINA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DÉLKA</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>NÁZEV</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>UMĚLEC</translation>
    </message>
    <message>
        <source>START</source>
        <translation>ZAČÁTEK</translation>
    </message>
    <message>
        <source>END</source>
        <translation>KONEC</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>ZÁKAZNÍK</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENTURA</translation>
    </message>
    <message>
        <source>USER DEFINED</source>
        <translation>STANOVENO UŽIVATELEM</translation>
    </message>
    <message>
        <source>CUTS</source>
        <translation>ZÁBĚRY</translation>
    </message>
    <message>
        <source>LAST CUT PLAYED</source>
        <translation>NAPOSLEDY HRANÝ ZÁBĚR</translation>
    </message>
    <message>
        <source>PLAY ORDER</source>
        <translation type="obsolete">POŘADÍ PŘEHRÁVÁNÍ</translation>
    </message>
    <message>
        <source>ENFORCE LENGTH</source>
        <translation>VYNUTIT DÉLKU</translation>
    </message>
    <message>
        <source>PRESERVE PITCH</source>
        <translation>ZACHOVAT VÝŠKU TÓNU</translation>
    </message>
    <message>
        <source>LENGTH DEVIATION</source>
        <translation>ODCHYLKA DÉLKY</translation>
    </message>
    <message>
        <source>OWNED BY</source>
        <translation>PATŘÍ</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>&amp;Rip
CD</source>
        <translation>&amp;Vytáhnout
z CD</translation>
    </message>
    <message>
        <source>Re&amp;ports</source>
        <translation>Z&amp;právy</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>VŠE</translation>
    </message>
    <message>
        <source></source>
        <translation>Project-Id-Version: amarok
Report-Msgid-Bugs-To: http://bugs.kde.org
POT-Creation-Date: 2010-05-20 04:55+0200
PO-Revision-Date: 2010-05-22 09:34+0200
Last-Translator: Pavel Fric
Language-Team: Czech &lt;kde-i18n-doc@kde.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Generator: Lokalize 1.0
Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n&gt;=2 &amp;&amp; n&lt;=4) ? 1 : 2;
</translation>
    </message>
    <message>
        <source>Are you sure you want to delete cart(s)</source>
        <translation>Jste si jistý, že chcete smazat tento vozík(y)</translation>
    </message>
    <message>
        <source>Delete Cart(s)</source>
        <translation>Smazat vozík(y)</translation>
    </message>
    <message>
        <source>Cart %06u is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation>Vozík %06u je používán jednou nebo více událostmi RDCatch.
Přesto smazat?</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>Událost RDCatch existuje</translation>
    </message>
    <message>
        <source>Deleting cart %06u will also empty the clipboard.
      <byte value="x9"/>Do you still want to proceed?</source>
        <translation>Smazání vozíku %06u vyprázdní také schránku
      <byte value="x9"/>Přesto pokračovat?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vyprázdnit schránku</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation type="obsolete">Sekvence</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="obsolete">Náhodný</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>RDLibrary - Host:</source>
        <translation type="obsolete">RDLibrary - Server: </translation>
    </message>
    <message>
        <source>, User:</source>
        <translation type="obsolete">, Uživatel:</translation>
    </message>
    <message>
        <source>Show Note Bubbles</source>
        <translation>Ukázat bzbliny s poznámkami</translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation>RDLibrary</translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation>Soubor(y) se zvukem nelze smazat!</translation>
    </message>
    <message>
        <source>Show Only First </source>
        <translation>Ukázat pouze první </translation>
    </message>
    <message>
        <source> Matches</source>
        <translation>Shody</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COMPOSER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CONDUCTOR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PUBLISHER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Cart Dragging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command-line option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALBUM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordCut</name>
    <message>
        <source>RDLibrary - Record</source>
        <translation>RDLibrary - Nahrávání</translation>
    </message>
    <message>
        <source>&amp;Description</source>
        <translation>&amp;Popis</translation>
    </message>
    <message>
        <source>&amp;Outcue</source>
        <translation>&amp;OUTCUE</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Původ</translation>
    </message>
    <message>
        <source>ISRC</source>
        <translation>ISRC</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Váha</translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation>Naposledy přehráno</translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation># přehrání</translation>
    </message>
    <message>
        <source>Cut is EVERGREEN</source>
        <translation>Záběr je EVERGREEN</translation>
    </message>
    <message>
        <source>Air Date/Time</source>
        <translation>Datum/Čas poslání</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Povoleno</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázáno</translation>
    </message>
    <message>
        <source>&amp;Start</source>
        <translation>&amp;Začátek</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <source>Daypart</source>
        <translation>Denní doba</translation>
    </message>
    <message>
        <source>&amp;Start Time</source>
        <translation>&amp;Počáteční čas</translation>
    </message>
    <message>
        <source>End Time</source>
        <translation>Koncový čas</translation>
    </message>
    <message>
        <source>Day of the Week</source>
        <translation>Den v týdnu</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Set All</source>
        <translation>Nastavit vše</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Smazat vše</translation>
    </message>
    <message>
        <source>NO SYNC!</source>
        <translation type="obsolete">ŽÁDNÉ SEŘIZOVÁNÍ!</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanály</translation>
    </message>
    <message>
        <source>Record Mode</source>
        <translation>Režim nahrávání</translation>
    </message>
    <message>
        <source>AutoTrim</source>
        <translation>Automatické zastřižení</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ruční</translation>
    </message>
    <message>
        <source>VOX</source>
        <translation>VOX</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Zvuk existuje</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Toto přepíše (smaže) stávající nahrávkun.
Přesto pokračovat?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Vyprázdnit schránku</translation>
    </message>
    <message>
        <source>This will empty the clipboard.
Do you still want to proceed?</source>
        <translation>Toto vyprázdní schránku.
Přesto pokračovat?</translation>
    </message>
    <message>
        <source>Missing Description</source>
        <translation>Chybí popis</translation>
    </message>
    <message>
        <source>You must provide a Cut Description!</source>
        <translation>Musíte zadat název záběru!</translation>
    </message>
    <message>
        <source>Invalid ISRC</source>
        <translation>Neplatný ISRC</translation>
    </message>
    <message>
        <source>The ISRC data is malformed or invalid!</source>
        <translation>Data ISRC jsou poškozena nebo neplatná!</translation>
    </message>
    <message>
        <source>Invalid Date</source>
        <translation>Neplatné datum</translation>
    </message>
    <message>
        <source>The Start Date is invalid!</source>
        <translation>Počáteční datum je neplatné!</translation>
    </message>
    <message>
        <source>The End Date is invalid!</source>
        <translation>Koncové datum je neplatné!</translation>
    </message>
    <message>
        <source>The End Date is prior to the Start Date!</source>
        <translation>Koncové datum leží před počátečním datem!</translation>
    </message>
    <message>
        <source>The End Date has already passed!
Do you still want to save?</source>
        <translation>Koncové datum již vypršelo!
Přesto uložit?</translation>
    </message>
    <message>
        <source>Invalid Time</source>
        <translation>Neplatný čas</translation>
    </message>
    <message>
        <source>The Start Time is invalid!</source>
        <translation>Počáteční čas je neplatný!</translation>
    </message>
    <message>
        <source>The End Time is invalid!</source>
        <translation>Koncový čas je neplatný!</translation>
    </message>
    <message>
        <source>The StartTime cannot be the same as the End Time!</source>
        <translation>Počáteční datum a koncové datum nemohou být stejné!</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Nelze spojit</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>Spojení s Core AudioEngine se nezdařilo</translation>
    </message>
    <message>
        <source>&amp;ISCI Code</source>
        <translation>Kód &amp;ISCI</translation>
    </message>
    <message>
        <source>AES ALARM</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
